Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1002)

Unified Diff: Source/core/html/HTMLEmbedElement.cpp

Issue 1115353002: Update renderer to layoutObject in core/html. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/HTMLElement.cpp ('k') | Source/core/html/HTMLFormControlElement.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/HTMLEmbedElement.cpp
diff --git a/Source/core/html/HTMLEmbedElement.cpp b/Source/core/html/HTMLEmbedElement.cpp
index 6c7e8b3440c949c07be884a0b92b387b8421e2d2..6ad165bca0f1787661acc9cfd6e115acbd03de1f 100644
--- a/Source/core/html/HTMLEmbedElement.cpp
+++ b/Source/core/html/HTMLEmbedElement.cpp
@@ -52,7 +52,7 @@ PassRefPtrWillBeRawPtr<HTMLEmbedElement> HTMLEmbedElement::create(Document& docu
return element.release();
}
-static inline LayoutPart* findPartRenderer(const Node* n)
+static inline LayoutPart* findPartLayoutObject(const Node* n)
{
if (!n->layoutObject())
n = Traversal<HTMLObjectElement>::firstAncestor(*n);
@@ -65,7 +65,7 @@ static inline LayoutPart* findPartRenderer(const Node* n)
LayoutPart* HTMLEmbedElement::existingLayoutPart() const
{
- return findPartRenderer(this);
+ return findPartLayoutObject(this);
}
bool HTMLEmbedElement::isPresentationAttribute(const QualifiedName& name) const
@@ -95,7 +95,7 @@ void HTMLEmbedElement::parseAttribute(const QualifiedName& name, const AtomicStr
if (pos != kNotFound)
m_serviceType = m_serviceType.left(pos);
if (!layoutObject())
- requestPluginCreationWithoutRendererIfPossible();
+ requestPluginCreationWithoutLayoutObjectIfPossible();
} else if (name == codeAttr) {
m_url = stripLeadingAndTrailingHTMLSpaces(value);
} else if (name == srcAttr) {
@@ -142,7 +142,7 @@ void HTMLEmbedElement::updateWidgetInternal()
RefPtrWillBeRawPtr<HTMLEmbedElement> protect(this); // Loading the plugin might remove us from the document.
// FIXME: Can we not have renderer here now that beforeload events are gone?
if (!layoutObject())
return;
@@ -155,7 +155,7 @@ bool HTMLEmbedElement::layoutObjectIsNeeded(const ComputedStyle& style)
return HTMLPlugInElement::layoutObjectIsNeeded(style);
// If my parent is an <object> and is not set to use fallback content, I
- // should be ignored and not get a renderer.
+ // should be ignored and not get a layoutObject.
ContainerNode* p = parentNode();
if (isHTMLObjectElement(p)) {
ASSERT(p->layoutObject());
@@ -142,7 +142,7 @@ void HTMLEmbedElement::updateWidgetInternal()
RefPtrWillBeRawPtr<HTMLEmbedElement> protect(this); // Loading the plugin might remove us from the document.
- // FIXME: Can we not have renderer here now that beforeload events are gone?
+ // FIXME: Can we not have layoutObject here now that beforeload events are gone?
if (!layoutObject())
return;
« no previous file with comments | « Source/core/html/HTMLElement.cpp ('k') | Source/core/html/HTMLFormControlElement.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698